Package: vinereg
Type: Package
Title: D-Vine Quantile Regression
Version: 0.10.0
Authors@R: c(
        person("Thomas", "Nagler",, "mail@tnagler.com", role = c("aut", "cre")),
        person("Dani", "Kraus",,, role = c("ctb"))
        )
Maintainer: Thomas Nagler <mail@tnagler.com>
Description: 
  Implements D-vine quantile regression models with
  parametric or nonparametric pair-copulas. See 
  Kraus and Czado (2017) <doi:10.1016/j.csda.2016.12.009> and
  Schallhorn et al. (2017) <arXiv:1705.08310>.
License: GPL-3
Imports: rvinecopulib (>= 0.6.1.1.2), kde1d (>= 1.0.2), Rcpp,
        assertthat
LinkingTo: rvinecopulib, RcppEigen, Rcpp, BH, wdm, RcppThread, kde1d
RoxygenNote: 7.2.3
Suggests: knitr, rmarkdown, ggplot2, AppliedPredictiveModeling,
        quantreg, tidyr, dplyr, purrr, scales, mgcv, testthat, covr
VignetteBuilder: knitr
URL: https://tnagler.github.io/vinereg/
BugReports: https://github.com/tnagler/vinereg/issues
Encoding: UTF-8
NeedsCompilation: yes
Packaged: 2024-02-09 14:43:38 UTC; n5
Author: Thomas Nagler [aut, cre],
  Dani Kraus [ctb]
Repository: CRAN
Date/Publication: 2024-02-09 16:00:02 UTC
Built: R 4.4.1; x86_64-apple-darwin24.0.0; 2024-10-19 11:35:11 UTC; unix
