# Generated by roxygen2: do not edit by hand

S3method(fitted,vinereg)
S3method(predict,vinereg)
S3method(print,vinereg)
S3method(summary,vinereg)
export(cll)
export(cpdf)
export(cpit)
export(plot_effects)
export(vinereg)
importFrom(Rcpp,sourceCpp)
importFrom(assertthat,assert_that)
importFrom(kde1d,kde1d)
importFrom(kde1d,pkde1d)
importFrom(kde1d,qkde1d)
importFrom(rvinecopulib,as_rvine_structure)
importFrom(rvinecopulib,bicop)
importFrom(rvinecopulib,dvine_structure)
importFrom(rvinecopulib,inverse_rosenblatt)
importFrom(rvinecopulib,rosenblatt)
importFrom(rvinecopulib,vinecop)
importFrom(stats,fitted)
importFrom(stats,logLik)
importFrom(stats,model.frame)
importFrom(stats,model.matrix)
importFrom(stats,pchisq)
importFrom(stats,predict)
importFrom(utils,capture.output)
importFrom(utils,modifyList)
useDynLib(vinereg, .registration = TRUE)
